@@ -5,7 +5,7 @@ This module is for platform-specific stuff.
 pub use self::inner::{force_cargo_color, read_path, write_path};
 
 use crate::consts;
-use crate::error::{Blame, MainError};
+use crate::error::MainError;
 use std::fs;
 
 use std::path::PathBuf;
@@ -29,14 +29,23 @@ pub fn current_time() -> u128 {
         .as_millis()
 }
 
+#[cfg(not(test))]
 pub fn cache_dir() -> Result<PathBuf, MainError> {
-    dirs::cache_dir()
+    dirs_next::cache_dir()
         .map(|dir| dir.join(consts::PROGRAM_NAME))
-        .ok_or_else(|| (Blame::Human, "Cannot get cache directory").into())
+        .ok_or_else(|| ("Cannot get cache directory").into())
 }
 
-pub fn script_cache_path() -> Result<PathBuf, MainError> {
-    cache_dir().map(|dir| dir.join("scripts"))
+#[cfg(test)]
+pub fn cache_dir() -> Result<PathBuf, MainError> {
+    lazy_static! {
+        static ref TEMP_DIR: tempfile::TempDir = tempfile::TempDir::new().unwrap();
+    }
+    Ok(TEMP_DIR.path().to_path_buf())
+}
+
+pub fn generated_projects_cache_path() -> Result<PathBuf, MainError> {
+    cache_dir().map(|dir| dir.join("projects"))
 }
 
 pub fn binary_cache_path() -> Result<PathBuf, MainError> {
@@ -50,9 +59,9 @@ pub fn templates_dir() -> Result<PathBuf, MainError> {
         }
     }
 
-    dirs::data_local_dir()
+    dirs_next::data_local_dir()
         .map(|dir| dir.join(consts::PROGRAM_NAME).join("templates"))
-        .ok_or_else(|| (Blame::Human, "Cannot get cache directory").into())
+        .ok_or_else(|| ("Cannot get cache directory").into())
 }
 
 #[cfg(unix)]
@@ -96,27 +105,14 @@ mod inner {
 pub mod inner {
     #![allow(non_snake_case)]
 
-    extern crate ole32;
-    extern crate shell32;
-    extern crate winapi;
-
     pub use super::*;
 
     use std::ffi::OsString;
-    use std::fmt;
 
     use std::io;
     use std::os::windows::ffi::{OsStrExt, OsStringExt};
     use std::path::{Path, PathBuf};
 
-    struct WinError(winapi::HRESULT);
-
-    impl fmt::Display for WinError {
-        fn fmt(&self, fmt: &mut fmt::Formatter) -> Result<(), fmt::Error> {
-            write!(fmt, "HRESULT({})", self.0)
-        }
-    }
-
     pub fn write_path<W>(w: &mut W, path: &Path) -> io::Result<()>
     where
         W: io::Write,
