@@ -135,3 +135,20 @@ fn test_script_including_relative() {
     )
     .unwrap()
 }
+
+#[test]
+fn script_with_same_name_as_dependency() {
+    let out = rust_script!("tests/data/time.rs").unwrap();
+    scan!(out.stdout_output();
+        ("Hello") => ()
+    )
+    .unwrap()
+}
+
+#[test]
+fn script_without_main_question_mark() {
+    let out = rust_script!("tests/data/question-mark").unwrap();
+    assert!(out
+        .stderr
+        .starts_with("Error: Os { code: 2, kind: NotFound, message:"));
+}
